@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: exceptionhandler.cc,v 1.4 2005/01/06 17:42:56 murrayc Exp $ */
+/* $Id: exceptionhandler.cc,v 1.5 2006/05/12 08:08:43 murrayc Exp $ */
 
 /* exceptionhandler.cc
  *
@@ -32,6 +32,7 @@
 GLIBMM_USING_STD(exception)
 GLIBMM_USING_STD(list)
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
 
 namespace
 {
@@ -157,3 +158,6 @@ void exception_handlers_invoke() throw()
 
 } // namespace Glib
 
+#endif //GLIBMM_EXCEPTIONS_ENABLED
+
+
